iflow.splines package
=====================

Submodules
----------

iflow.splines.cubic module
--------------------------

.. automodule:: iflow.splines.cubic
   :members:
   :undoc-members:
   :show-inheritance:

iflow.splines.linear module
---------------------------

.. automodule:: iflow.splines.linear
   :members:
   :undoc-members:
   :show-inheritance:

iflow.splines.quadratic module
------------------------------

.. automodule:: iflow.splines.quadratic
   :members:
   :undoc-members:
   :show-inheritance:

iflow.splines.rational\_quadratic module
----------------------------------------

.. automodule:: iflow.splines.rational_quadratic
   :members:
   :undoc-members:
   :show-inheritance:

iflow.splines.spline module
---------------------------

.. automodule:: iflow.splines.spline
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: iflow.splines
   :members:
   :undoc-members:
   :show-inheritance:
